@@ -9,10 +9,12 @@ import plotly.graph_objs as go
 import scipy.stats
 from plotly.offline import plot as offline_plot
 
-__all__ = ['hydroviewer', 'forecast_stats', 'forecast_records', 'forecast_ensembles', 'historic_simulation',
-           'daily_averages', 'monthly_averages', 'flow_duration_curve', 'probabilities_table', 'return_periods_table',
-           'corrected_historical', 'corrected_scatterplots', 'corrected_day_average', 'corrected_month_average',
-           'corrected_volume_compare']
+from .analysis import compute_daily_statistics
+
+__all__ = ['hydroviewer', 'forecast_stats', 'forecast_records', 'forecast_ensembles', 'daily_variance',
+           'historic_simulation', 'daily_averages', 'monthly_averages', 'flow_duration_curve', 'probabilities_table',
+           'return_periods_table', 'corrected_historical', 'corrected_scatterplots', 'corrected_day_average',
+           'corrected_month_average', 'corrected_volume_compare', 'daily_stats']
 
 
 # FUNCTIONS THAT PROCESS THE RESULTS OF THE API INTO A PLOTLY PLOT OR DICTIONARY
@@ -479,6 +481,85 @@ def daily_averages(dayavg: pd.DataFrame, titles: dict = False, outformat: str =
     raise ValueError('Invalid outformat chosen. Choose plotly, plotly_scatters, or plotly_html')
 
 
+def daily_variance(daily_variance: pd.DataFrame, titles: dict = None, outformat: str = 'plotly') -> go.Figure:
+    """
+    A dataframe of daily variances computed by the geoglows.analysis.compute_daily_variance function
+
+    Args:
+      daily_variance: dataframe of values to plot coming from geoglows.analysis.compute_daily_variance
+      titles: (dict) Extra info to show on the title of the plot. For example:
+        {'Reach ID': 1234567, 'Drainage Area': '1000km^2'}
+      outformat: either 'plotly' (python object, default), 'plotly_scatters', or 'plotly_html'
+
+    returns:
+      plot of standard deviation and plot of the graph of the low flows
+    """
+    data = [
+        go.Scatter(
+            x=daily_variance['date'],
+            y=daily_variance['flow_std'],
+            name="Daily Standard Deviation"
+        )
+    ]
+    if outformat == 'plotly_scatters':
+        return data
+    figure = go.Figure(data=data, layout=go.Layout(_build_title('Daily Flow Standard Deviation', titles)))
+    if outformat == 'plotly':
+        return figure
+    elif outformat == 'plotly_html':
+        return offline_plot(
+            figure,
+            config={'autosizable': True, 'responsive': True},
+            output_type='div',
+            include_plotlyjs=False
+        )
+    raise ValueError('Invalid outformat chosen. Choose plotly or plotly_html')
+
+
+def daily_stats(hist: pd.DataFrame, titles: dict = None, outformat: str = 'plotly') -> go.Figure:
+    """
+    Plots a graph with statistics for each day of year
+
+    Args:
+        hist: dataframe of values to plot
+        titles: (dict) Extra info to show on the title of the plot. For example:
+            {'Reach ID': 1234567, 'Drainage Area': '1000km^2'}
+        outformat: either 'plotly' (python object, default), 'plotly_scatters', or 'plotly_html'
+
+    returns:
+        plot of the graph of the low flows
+    """
+
+    stats_df = compute_daily_statistics(hist)
+
+    data = [
+        go.Scatter(
+            x=stats_df.index.tolist(),
+            y=stats_df[column].tolist(),
+            name=column
+        ) for column in stats_df.columns
+    ]
+
+    if outformat == 'plotly_scatters':
+        return data
+    layout = go.Layout(
+        title=_build_title('Daily Average Streamflow (Simulated)', titles),
+        yaxis={'title': 'Streamflow (m<sup>3</sup>/s)', 'range': [0, 'auto']},
+        xaxis={'title': 'Date (UTC +0:00)', 'hoverformat': '%b %d', 'tickformat': '%b'},
+    )
+    figure = go.Figure(data=data, layout=layout)
+    if outformat == 'plotly':
+        return figure
+    elif outformat == 'plotly_html':
+        return offline_plot(
+            figure,
+            config={'autosizable': True, 'responsive': True},
+            output_type='div',
+            include_plotlyjs=False
+        )
+    raise ValueError('Invalid outformat chosen. Choose plotly or plotly_html')
+
+
 def monthly_averages(monavg: pd.DataFrame, titles: dict = False, outformat: str = 'plotly') -> go.Figure:
     """
     Makes the daily_averages data and metadata into a plotly plot
@@ -697,7 +778,7 @@ def corrected_historical(corrected: pd.DataFrame, simulated: pd.DataFrame, obser
         simulated: the csv response from historic_simulation
         observed: the dataframe of observed data. Must have a datetime index and a single column of flow values
         rperiods: the csv response from return_periods
-        outformat: either 'json', 'plotly', or 'plotly_html' (default plotly)
+        outformat: either 'plotly', or 'plotly_html' (default plotly)
         titles: (dict) Extra info to show on the title of the plot. For example:
             {'Reach ID': 1234567, 'Drainage Area': '1000km^2'}
 
@@ -1132,3 +1213,40 @@ def _rperiod_scatters(startdate: str, enddate: str, rperiods: pd.DataFrame, y_ma
             template(f'50 Year: {r50}', (r50, r50, r100, r100), colors['50 Year']),
             template(f'100 Year: {r100}', (r100, r100, rmax, rmax), colors['100 Year']),
         ]
+
+
+def plot_low_flows(data: pd.DataFrame, rps: tuple = (2, 5, 10, 25, 50)):
+    """
+    Plots the graph for the standard deviation over a year and the graph of low flows by day of the year
+
+    Args:
+        data: dataframe of values to plot
+        rps: tuple for the return periods - default is (2, 5, 10, 25, 50)
+
+    returns:
+        plot of the graph of the low flows
+    """
+    data['datetime'] = pd.to_datetime(data['datetime'])
+    streamflow_data = pd.DataFrame()
+    streamflow_data['streamflow'] = data['streamflow_m^3/s']
+    streamflow_data['day'] = data['datetime'].dt.strftime('%m-%d')
+    daily_averages = streamflow_data.groupby('day').mean()
+    averages = [
+        go.Scatter(
+            x=daily_averages.index,
+            y=daily_averages['streamflow'],
+            name="daily-averages"
+        )
+    ]
+    layout = go.Layout(xaxis={'type': 'category'}, title="Low flows by day of year")
+    plot = go.Figure(data=averages, layout=layout)
+    for rp in rps:
+        quantile = streamflow_data.groupby('day').quantile(1 / rp)
+        plot.add_trace(
+            go.Scatter(
+                x=daily_averages.index,
+                y=quantile['streamflow'],
+                name=f'{rp}_year'
+            )
+        )
+    return plot
